# fish completion for ponysay-tool-tool         -*- shell-script -*-

complete --command ponysay-tool-tool --description 'Message spoken by the pony' --no-files --arguments " MESSAGE"
complete --command ponysay-tool-tool --description 'Show summary of options' --short-option h --long-option help
complete --command ponysay-tool-tool --description 'Show help summary, with colour even if piped' --long-option help-colour
complete --command ponysay-tool-tool --description 'Show version of program' --short-option v --long-option version
complete --command ponysay-tool-tool --description 'Compress message' --short-option c --long-option compact
complete --command ponysay-tool-tool --description 'List all MLP:FiM ponies' --short-option l --long-option list
complete --command ponysay-tool-tool --description 'List all MLP:FiM ponies, with symlink mapping' --short-option L --long-option symlist
complete --command ponysay-tool-tool --description 'List all ponies' --short-option A --long-option all
complete --command ponysay-tool-tool --description 'List all ponies, with symlink mapping' --long-option symall
complete --command ponysay-tool-tool --description 'List all balloon styles' --arguments "  ( '/usr/bin/ponysay-tool' --balloonlist ) " --short-option b --long-option balloonlist
complete --command ponysay-tool-tool --description 'Print just the pony' --short-option o --long-option pony-only
complete --command ponysay-tool-tool --description 'Print pony metadata' --short-option i --long-option info
complete --command ponysay-tool-tool --description 'Specify the pony that should printed' --arguments "  ( '/usr/bin/ponysay-tool' --onelist ) " --short-option f --long-option file
complete --command ponysay-tool-tool --description 'Specify the [extra]pony that should printed' --arguments "  ( '/usr/bin/ponysay-tool' --Onelist ) " --short-option F --long-option any-pony
complete --command ponysay-tool-tool --description 'Specify the pony that should quote herself' --arguments "  ( '/usr/bin/ponysay-tool' --quoters ) " --short-option q --long-option quote
complete --command ponysay-tool-tool --description 'Specify message balloon style' --arguments "  ( '/usr/bin/ponysay-tool' --balloonlist ) " --short-option b --long-option balloon
complete --command ponysay-tool-tool --description 'Specify wrapping column' --no-files --arguments " none inherit 100 60" --short-option W --long-option wrap
complete --command ponysay-tool-tool --description 'Specify colour of the balloon, balloon link and message' --no-files --long-option colour
complete --command ponysay-tool-tool --description 'Restrict randomly selected ponies' --no-files --arguments " kind=KIND group=GROUP coat=COAT eye=EYE mane=MANE aura=AURA" --short-option r --long-option restrict
